<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ToggleBlockVisibility</name>
    <message>
        <location filename="../ToggleBlockVisibilityInit.js" line="+2"/>
        <source>&amp;Toggle Visibility</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zmień widoczność</translatorcomment>
        <translation>&amp;Przełącz widoczność</translation>
    </message>
</context>
</TS>
